@@ -66,10 +66,6 @@ flickr.getMongoRange = function (host, db, coll, field, callback) {
             // an error message on the console.
             if (response.error || response.result.data.length === 0) {
                 max = null;
-
-                if (response.error) {
-                    tangelo.fatalError("flickr.getMongoRange()", "error: could not retrieve max value from " + host + ":/" + db + "/" + coll + ":" + field);
-                }
             } else {
                 max = response.result.data[0][field];
             }
@@ -88,10 +84,6 @@ flickr.getMongoRange = function (host, db, coll, field, callback) {
                     // be retrieved.
                     if (response.error || response.result.data.length === 0) {
                         min = null;
-
-                        if (response.error) {
-                            tangelo.fatalError("flickr.getMongoRange()", "could not retrieve min value from " + host + ":/" + db + "/" + coll + ":" + field);
-                        }
                     } else {
                         min = response.result.data[0][field];
                     }
@@ -139,8 +131,8 @@ function retrieveData(initial) {
 
     // Construct a query that selects times between the two ends of the slider.
     timequery = {
-        $and : [{'date' : {$gte : {"$date" : times[0]}}},
-                {'date' : {$lte : {"$date" : times[1]}}}]
+        $and : [{"datetaken" : {$gte : {"$date" : times[0]}}},
+                {"datetaken" : {$lte : {"$date" : times[1]}}}]
     };
 
     // Get the hashtag text and split it into several tags.
@@ -172,7 +164,7 @@ function retrieveData(initial) {
         data: {
             query: JSON.stringify(query),
             limit: d3.select("#record-limit").node().value,
-            sort: JSON.stringify([['date', 1]])
+            sort: JSON.stringify([["datetaken", 1]])
         },
         dataType: 'json',
         success: function (response) {
@@ -209,7 +201,7 @@ function retrieveData(initial) {
             //
             // Extract some information from the date.
             data = response.result.data.map(function (d) {
-                var date = new Date(d.date.$date);
+                var date = new Date(d.datetaken.$date);
 
                 d.month = flickr.monthName(date);
                 d.day = flickr.dayName(date);
@@ -400,13 +392,16 @@ function retrieveData(initial) {
                                     msg,
                                     date;
 
-                                date = new Date(d.date.$date);
+                                date = new Date(d.datetaken.$date);
 
                                 msg = "";
                                 msg += "<b>Date:</b> " + flickr.dateformat(date) + "<br>\n";
                                 msg += "<b>Location:</b> (" + d.location[1] + ", " + d.location[0] + ")<br>\n";
-                                msg += "<b>Author:</b> " + d.author + "<br>\n";
+                                msg += "<b>Owner:</b> " + d.owner + "<br>\n";
                                 msg += "<b>Description:</b> " + d.title + "<br>\n";
+                                if (d.url) {
+                                    msg += "<img src=" + d.url + ">";
+                                }
 
                                 cfg = {
                                     html: true,
@@ -475,11 +470,25 @@ function getMinMaxDates(zoom) {
 
     // Get the earliest and latest times in the collection, and set the slider
     // range/handles appropriately.
-    flickr.getMongoRange(flickr.config.server, flickr.config.db, flickr.config.coll, "date", function (min, max) {
+    flickr.getMongoRange(flickr.config.server, flickr.config.db, flickr.config.coll, "datetaken", function (min, max) {
         var gmap_cfg,
             options,
             div;
 
+        if (min === null || max === null) {
+            d3.select("#map")
+                .style("font-size", "14pt")
+                .style("padding-top", "20%")
+                .style("padding-left", "20%")
+                .style("padding-right", "20%")
+                .style("text-align", "center")
+                .html("There doesn't seem to be a Mongo instance at <em>" + flickr.config.server + "</em>" +
+                    ", with database <em>" + flickr.config.db + "</em> and collection <em>" + flickr.config.coll + "</em>" +
+                    ", or there is no data there." +
+                    "  See these <a href=\"http://localhost:8080/docs/setup.html#flickr-metadata-maps\">instructions</a> for help setting this up.");
+            return;
+        }
+
         // Retrieve the timestamps from the records.
         min = min.$date;
         max = max.$date;
@@ -555,7 +564,7 @@ window.onload = function () {
     // Create control panel.
     $("#control-panel").controlPanel();
 
-    tangelo.defaults("config.json", function (config, status, error) {
+    tangelo.config("config.json", function (config, status, error) {
         var buttons,
             i,
             checkbox,
